/*
 * Copyright (c) 1997-2000 Centro de Informtica - UFPE
 */

package frames;

import java.awt.*;
import java.awt.event.*;

/**
 * Esta classe representa as janelas de confirmao e avisos.
 */
public class DialogMensagem extends Dialog {

    // Panel que contm o boto "Ok" e o Label da mensagem.
    private Panel pnl = new Panel();
    // Boto "Ok".
    private Button btnOk = new Button();
    // Label com a mensagem.
    private Label lblMensagem = new Label();
    // Layout que organiza os botes, labels, etc. na tela.
    private FlowLayout flowLayout = new FlowLayout();


    /**
     * Construtor da classe. Inicializa a janela da mensagem.
     *
     * @param frame Frame que chamou o dialog - o owner.
     * @param title Ttulo do dialog.
     * @param mensagem Mensagem a ser impressa na tela.
     */
    public DialogMensagem(Frame frame, String title, String mensagem) {
        super(frame, title, true);
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);
        try  {
            jbInit();
            lblMensagem.setText(mensagem);
            add(pnl);
            pack();
        }
        catch (Exception excecao) {
            excecao.printStackTrace();
        }
    }

    // Mtodo auxiliar do construtor.
    private void jbInit() throws Exception {
        btnOk.setLabel("OK");
        btnOk.addActionListener(new DialogMensagemBtnOkActionAdapter(this));
        lblMensagem.setText("   label");
        pnl.setSize(new Dimension(289, 59));
        pnl.setLayout(flowLayout);
        pnl.add(lblMensagem, null);
        pnl.add(btnOk, null);
        setSize(150,50);
    }

    /**
     * Sobreposicao do metodo para fechar a janela. Chamado quando se clica no
     * "X" do canto superior direito da tela.
     *
     * @param e Evento ocorrido.
     */
    protected void processWindowEvent(WindowEvent e) {
        if (e.getID() == WindowEvent.WINDOW_CLOSING) {
            dispose();
        }
        super.processWindowEvent(e);
    }

    /**
     * ActionPerformed do boto Ok. Fecha a janela.
     *
     * @param e Evento ocorrido.
     */
    public void btnOkActionPerformed(ActionEvent e) {
        dispose();
    }

}


/**
 * Listener criado pelo JBuilder.
 *  o responsavel pelo boto "Ok".
 */
class DialogMensagemBtnOkActionAdapter implements java.awt.event.ActionListener {

    private DialogMensagem adaptee;

    /**
     * Construtor da classe.
     *
     * @param adaptee Dialog da mensagem, onde a ao ocorreu.
     */
    public DialogMensagemBtnOkActionAdapter(DialogMensagem adaptee) {
        this.adaptee = adaptee;
    }

    /**
     * Mtodo chamado quando o boto  pressionado.
     *
     * @param e Evento ocorrido.
     */
    public void actionPerformed(ActionEvent e) {
        adaptee.btnOkActionPerformed(e);
    }

}