/*
 * Copyright (c) 1997-2000 Centro de Informtica - UFPE
 */

package frames;

import java.awt.*;
import java.awt.event.*;
import frames.banco.*;
import frames.conta.*;

/**
 * Esta classe representa a janela do cadastro de contas.
 */
public class FrameCadastro extends Frame {

    // Label do nmero da conta.
    private Label lblNumero = new Label();
    // Campo de texto onde ser digitado o nmero da conta a ser cadastrada.
    private TextField textFieldNumero = new TextField();
    // Boto de inserir.
    private Button btnInserir = new Button();
    // Boto de cancelar.
    private Button btnCancelar = new Button();

    // a classe de fachada do sistema
    private Banco banco;

    // Panel que contm o boto e o label do nmero da conta.
    private Panel pnl = new Panel();
    // Panel que contm os botes inserir e cancelar.
    private Panel pnl2 = new Panel();
    // Layout que organiza os botes, text fields, etc. na tela.
    private FlowLayout flowLayout = new FlowLayout();

    /**
     * Construtor da classe. Inicializa a janela do cadastro.
     *
     * @param banco A fachada do sistema.
     */
    public FrameCadastro(Banco banco) {
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);
        try  {
            this.banco = banco;   // pegando o banco passado como paramentro
            jbInit();
        }
        catch (Exception excecao) {
            excecao.printStackTrace();
        }
    }

    // Mtodo auxiliar do construtor.
    private void jbInit() throws Exception {
        this.setBackground(Color.lightGray);
        this.setSize(new Dimension(323, 118));
        this.setTitle("Cadastrar uma Conta");
        lblNumero.setText("Numero:");
        textFieldNumero.setBackground(Color.white);
        textFieldNumero.setColumns(20);
        btnInserir.setLabel("Inserir");
        btnInserir.addActionListener(new FrmCadastroBtnInserirActionAdapter(this));
        btnCancelar.setLabel("Cancelar");
        btnCancelar.addActionListener(new FrmCadastroBtnCancelarActionAdapter(this));
        this.setLayout(flowLayout);
        this.add(pnl, null);
        pnl.add(lblNumero, null);
        pnl.add(textFieldNumero, null);
        this.add(pnl2, null);
        pnl2.add(btnInserir, null);
        pnl2.add(btnCancelar, null);
        setSize(300,100);
    }

    /**
     * Insere uma nova conta no cadastro.
     *
     * @param e Evento ocorrido.
     */
    public void btnInserirActionPerformed(ActionEvent e) {  // inserir a conta
        try {
            Conta nova = new Conta(textFieldNumero.getText());
            banco.cadastrar(nova);
            this.setVisible(false);
        }
        catch(ContaJaExisteException cee){
            DialogMensagem dgMsg =
                new DialogMensagem(new Frame(), "Conta existente", "Conta "
                                   + textFieldNumero.getText() + " ja existe!");
            dgMsg.setVisible(true);
        }
        catch(NumberFormatException cee){
            DialogMensagem dgMsg =
                new DialogMensagem(new Frame(), "Valor invlido",
                                   "Digite um nmero!");
            dgMsg.setVisible(true);
        }
        catch(IllegalArgumentException iae){
            DialogMensagem dgMsg =
                new DialogMensagem(new Frame(), "Erro Interno", "Entre em "
                                   + "contato com o operador do sistema!");
            dgMsg.setVisible(true);
        }
        finally {
            textFieldNumero.setText("");
        }
    }

    /**
     * Cancela o cadastro da conta e sai da janela.
     *
     * @param e Evento ocorrido.
     */
    public void btnCancelarActionPerformed(ActionEvent e) {
        textFieldNumero.setText("");
        this.setVisible(false);
    }

    /**
     * Sobreposicao do metodo para fechar a janela. Chamado quando se clica no
     * "X" do canto superior direito da tela.
     *
     * @param e Evento ocorrido.
     */
    protected void processWindowEvent(WindowEvent e) {
        textFieldNumero.setText("");
        if (e.getID() == WindowEvent.WINDOW_CLOSING) {
            dispose();
        }
        super.processWindowEvent(e);
    }

}


/**
 * Listener criado pelo JBuilder.
 *  o responsavel pelo boto "Inserir".
 */
class FrmCadastroBtnInserirActionAdapter
        implements java.awt.event.ActionListener {

    // Frame do cadastro.
    private FrameCadastro adaptee;

    /**
     * Construtor da classe.
     *
     * @param adaptee Frame do cadastro, onde a ao ocorreu.
     */
    public FrmCadastroBtnInserirActionAdapter(FrameCadastro adaptee) {
        this.adaptee = adaptee;
    }

    /**
     * Mtodo chamado quando o boto  pressionado.
     *
     * @param e Evento ocorrido.
     */
    public void actionPerformed(ActionEvent e) {
        adaptee.btnInserirActionPerformed(e);
    }

}


/**
 * Listener criado pelo JBuilder.
 *  o responsavel pelo boto "Cancelar".
 */
class FrmCadastroBtnCancelarActionAdapter
        implements java.awt.event.ActionListener {

    // Frame do cadastro.
    private FrameCadastro adaptee;

    /**
     * Construtor da classe.
     *
     * @param adaptee Frame do cadastro, onde a ao ocorreu.
     */
    public FrmCadastroBtnCancelarActionAdapter(FrameCadastro adaptee) {
        this.adaptee = adaptee;
    }

    /**
     * Mtodo chamado quando o boto  pressionado.
     *
     * @param e Evento ocorrido.
     */
    public void actionPerformed(ActionEvent e) {
        adaptee.btnCancelarActionPerformed(e);
    }

}