/*
 * Copyright (c) 1997-2000 Centro de Informtica - UFPE
 */

package frames.banco;

import frames.conta.*;

/**
 * Esta classe modela um Banco.  a fachada do sistema.
 */
public class Banco {

    // Cadastro de contas do banco: tamanho mximo = 20.
    private CadastroContas contas;

    /**
     *
     */
    public Banco() {
        contas = new CadastroContas(new ConjuntoContas(20));
    }

    /**
     * Cadastra uma conta no banco.
     *
     * @param conta Conta a ser cadastrada.
     *
     * @throws ContaJaExisteException se a conta recebida j existir.
     * @throws IllegalArgumentException se a conta recebida for null.
     */
    public void cadastrar(Conta conta) throws ContaJaExisteException {
        contas.cadastrar(conta);
    }

    /**
     * Remove uma conta do banco.
     *
     * @param numero Numero da conta a ser removida
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada no banco.
     */
    public void remover(String numero) throws ContaNaoEncontradaException {
        contas.remover(numero);
    }

    /**
     * Debita um determinado valor de uma determinada conta.
     *
     * @param numero Numero da conta.
     * @param valor Valor a ser debitado.
     *
     * @throws SaldoInsuficienteException se o valor recebido for maior que o
     *                                    saldo disponivel.
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada no banco.
     */
    public void debitar(String numero, double valor)
                throws SaldoInsuficienteException, ContaNaoEncontradaException {
        contas.debitar(numero, valor);
    }

    /**
     * Credita um determinado valor em uma determinada conta.
     *
     * @param numero Numero da conta.
     * @param valor Valor a ser creditado.
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada no banco.
     */
    public void creditar(String numero, double valor)
               throws ContaNaoEncontradaException {
        contas.creditar(numero, valor);
    }

    /**
     * Procura uma determinada conta no banco.
     *
     * @param numero Numero da conta a ser procurada.
     *
     * @return A conta, caso tenha sido encontrada.
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada no banco.
     */
    public Conta procurar(String numero) throws ContaNaoEncontradaException {
        return contas.procurar(numero);
    }

}