/*
 * Copyright (c) 1997-2000 Centro de Informtica - UFPE
 */

package frames.conta;

/**
 * Esta classe modela um Cadastro de Contas.
 */
public class CadastroContas {

    private RepositorioContas contas;

    /**
     * Inicializa o cadastro com o valor mximo recebido.
     *
     * @param tamanho Tamanho mximo do cadastro.
     */
    public CadastroContas(RepositorioContas contas) {
        if (contas != null)
            this.contas = contas;
        else
            throw new IllegalArgumentException();
    }

    /**
     * Cadastra uma conta.
     *
     * @param conta Conta a ser cadastrada.
     *
     * @throws ContaJaExisteException se a conta recebida j existir.
     * @throws IllegalArgumentException se a conta recebida for null.
     */
    public void cadastrar(Conta conta) throws ContaJaExisteException {
        String numero;

        if (conta != null) {
            numero = conta.getNumero();
            if (!contas.existe(numero))
                contas.inserir(conta);
            else
                throw new ContaJaExisteException(numero);
        } else
              throw new IllegalArgumentException();
    }

    /**
     * Remove uma conta do cadastro.
     *
     * @param numero Numero da conta a ser removida
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada.
     */
    public void remover(String numero) throws ContaNaoEncontradaException {
        contas.remover(numero);
    }

    /**
     * Debita um determinado valor de uma determinada conta.
     *
     * @param numero Numero da conta.
     * @param valor Valor a ser debitado.
     *
     * @throws SaldoInsuficienteException se o valor recebido for maior que o
     *                                    saldo disponivel.
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada.
     */
    public void debitar(String numero, double valor)
                throws SaldoInsuficienteException, ContaNaoEncontradaException {
        Conta conta = contas.procurar(numero);
        conta.debitar(valor);
    }

    /**
     * Credita um determinado valor em uma determinada conta.
     *
     * @param numero Numero da conta.
     * @param valor Valor a ser creditado.
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada.
     */
    public void creditar(String numero, double valor)
                throws ContaNaoEncontradaException {
        Conta conta = contas.procurar(numero);
        conta.creditar(valor);
    }

    /**
     * Procura uma determinada conta no cadastro.
     *
     * @param numero Numero da conta a ser procurada.
     *
     * @return A conta, caso tenha sido encontrada.
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta cadastrada.
     */
   public Conta procurar(String numero) throws ContaNaoEncontradaException {
        return contas.procurar(numero);
    }

}