/*
 * Copyright (c) 1997-2000 Centro de Informtica - UFPE
 */

package frames.conta;

/**
 * Esta classe modela um Conjunto de Contas.
 */
public class ConjuntoContas implements RepositorioContas {

    // Array de contas.
    private Conta[] contas;

    // Posio do ltimo elemento no array.
    private int indice;

    /**
     * Inicializa o conjunto de contas com o tamanho mximo recebido.
     *
     * @param tamanho Tamanho mximo do conjunto.
     */
    public ConjuntoContas (int tamanho) {
        contas = new Conta[tamanho];
        indice = 0;
    }

    /**
     * Insere uma conta no conjunto.
     *
     * @param conta Conta a ser inserida.
     *
     * @throws IllegalArgumentException se a conta recebida for null.
     */
    public void inserir(Conta conta) {
        if (conta != null) {
            contas[indice] = conta;
            indice = indice + 1;
        } else
            throw new IllegalArgumentException();
    }

    /**
     * Remove uma conta do conjunto.
     *
     * @param numero Numero da conta a ser removida
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta do conjunto.
     */
    public void remover(String numero) throws ContaNaoEncontradaException {
        int j;

        if (existe(numero)) {
            for (j = procurarIndice(numero); j < indice; j++)
                contas[j] = contas[j+1];
            indice = indice - 1;
        }
        else
            throw new ContaNaoEncontradaException(numero);
    }

    /**
     * Procura uma determinada conta no conjunto.
     *
     * @param numero Numero da conta a ser procurada.
     *
     * @return A conta, caso tenha sido encontrada.
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta do conjunto.
     */
    public Conta procurar(String numero) throws ContaNaoEncontradaException {
        Conta conta = null;
        int i = this.procurarIndice(numero);

        if (i == indice)
            throw new ContaNaoEncontradaException(numero);
        else
            conta = contas[i];
        return conta;
    }


    /**
     * Checa se uma determinada conta existe.
     *
     * @param numero Numero da conta a ser procurada.
     *
     * @return true se a conta existir, false caso contrrio.
     */
    public boolean existe(String numero) {
        int i = this.procurarIndice(numero);

        return (i != indice);
    }

    /*
     * Procura o ndice de uma determinada conta, caso esta no exista,
     * o valor retornado  o ndice final do array.
     */
    private int procurarIndice(String numero) {
        int i = 0;
        boolean achou = false;

        while ((!achou) && (i < indice)) {
            if ((contas[i].getNumero()).equals(numero))
                achou = true;
            else
                i = i + 1;
        }
        return i;
    }

}