/*
 * Copyright (c) 1997-2000 Centro de Informtica - UFPE
 */

package frames.conta;

/**
 * Esta classe modela uma Conta.
 */
public class Conta {

    // Numero da conta.
    private String numero;

    // Saldo disponivel.
    private double saldo;
    
    /**
     * Inicializa uma conta com os parmetros recebidos.
     *
     * @param Numero da conta.
     * @param Saldo inicial.
     */
    public Conta(String numero, double saldo) {
        this.numero = numero;
        this.saldo = saldo;
    }
    
    /**
     * Inicializa uma conta com o saldo zero.
     *
     * @param Numero da conta.
     */
    public Conta(String numero) {
        this.numero = numero;
        saldo = 0;
    }
    
    /**
     * Retorna o nmero da conta.
     *
     * @return O nmero da conta.
     */
    public String getNumero() {
        return numero;
    }
    
    /**
     * Retorna o saldo da conta.
     *
     * @return O saldo.
     */
    public double getSaldo() {
        return saldo;
    }
    
    /**
     * Credita um determinado valor na conta.
     *
     * @param valor Valor a ser creditado.
     */
    public void creditar(double valor) {
        saldo = saldo + valor;
    }
    
    /**
     * Debita um determinado valor da conta.
     *
     * @param valor Valor a ser debitado.
     *
     * @throws SaldoInsuficienteException se o saldo disponivel na conta for
     *                                    menor que o valor recebido.
     */
    public void debitar(double valor) throws SaldoInsuficienteException {
        if (valor <= saldo)
            saldo = saldo - valor;
        else {
            throw new SaldoInsuficienteException(saldo, numero);
        }
    }
    
    /**
     * Transfere o valor desta conta para a conta recebida.
     *
     * @param conta Conta para onde o valor ser transferido.
     * @param valor Valor a ser transferido.
     *
     * @throws SaldoInsuficienteException se o saldo disponivel na conta for
     *                                    menor que o valor recebido.
     */
    public void transferir(Conta conta, double valor) 
                throws SaldoInsuficienteException {
        this.debitar(valor);
        conta.creditar(valor);
    }

}