/*
 * Copyright (c) 1997-2000 Centro de Informtica - UFPE
 */

package frames.conta;

/**
 * Esta classe modela um Conjunto de Contas.
 */
public interface RepositorioContas {

    /**
     * Insere uma conta no repositorio.
     *
     * @param conta Conta a ser inserida.
     *
     * @throws IllegalArgumentException se a conta recebida for null.
     */
    public void inserir(Conta conta);

    /**
     * Remove uma conta do repositorio.
     *
     * @param numero Numero da conta a ser removida
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta do repositorio.
     */
    public void remover(String numero) throws ContaNaoEncontradaException;

    /**
     * Procura uma determinada conta no repositorio.
     *
     * @param numero Numero da conta a ser procurada.
     *
     * @return A conta, caso tenha sido encontrada.
     *
     * @throws ContaNaoEncontradaException se o numero recebido no representar
     *                                     uma conta do repositorio.
     */
    public Conta procurar(String numero) throws ContaNaoEncontradaException;


    /**
     * Checa se uma determinada conta existe.
     *
     * @param numero Numero da conta a ser procurada.
     *
     * @return true se a conta existir, false caso contrrio.
     */
    public boolean existe(String numero);

}